from setuptools import setup

setup(name='gwapy',
      version='0.2',
      description='gwapy',
      url='',
      author='bat-cha',
      author_email='baptiste.chatrain@amadeus.com',
      license='MIT',
      packages=['gwapy'],
      zip_safe=False)